# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class CustomersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_customer(self, **kwargs):  # noqa: E501
        """Creates a customer  # noqa: E501

        _in snippets: platform.api.customers.addCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_customer(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCustomerModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_customer_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_customer_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_customer_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a customer  # noqa: E501

        _in snippets: platform.api.customers.addCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_customer_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCustomerModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_customer" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_customer_tags(self, customer_id, **kwargs):  # noqa: E501
        """Adds tags to a customer  # noqa: E501

        _in snippets: platform.api.customers.addCustomerTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_customer_tags(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param list[TagModel] body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_customer_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_customer_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def add_customer_tags_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Adds tags to a customer  # noqa: E501

        _in snippets: platform.api.customers.addCustomerTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_customer_tags_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param list[TagModel] body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_customer_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `add_customer_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/tags', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_identity(self, customer_id, **kwargs):  # noqa: E501
        """Adds an identity to a customer  # noqa: E501

        _in snippets: platform.api.customers.addIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_identity(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param CustomerIdentityModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_identity_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_identity_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def add_identity_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Adds an identity to a customer  # noqa: E501

        _in snippets: platform.api.customers.addIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_identity_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param CustomerIdentityModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_identity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `add_identity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/identities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_or_update_customer(self, **kwargs):  # noqa: E501
        """Creates or updates a customer  # noqa: E501

        _in snippets: platform.api.customers.addOrUpdateCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_or_update_customer(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCustomerModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_or_update_customer_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_or_update_customer_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_or_update_customer_with_http_info(self, **kwargs):  # noqa: E501
        """Creates or updates a customer  # noqa: E501

        _in snippets: platform.api.customers.addOrUpdateCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_or_update_customer_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCustomerModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_or_update_customer" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_instant_app(self, customer_id, **kwargs):  # noqa: E501
        """Creates an Instant App for the customer.  # noqa: E501

        _in snippets: platform.api.customers.createInstantApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_instant_app(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param InstantAppModel body:
        :return: InstantAppModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_instant_app_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_instant_app_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def create_instant_app_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Creates an Instant App for the customer.  # noqa: E501

        _in snippets: platform.api.customers.createInstantApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_instant_app_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param InstantAppModel body:
        :return: InstantAppModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_instant_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `create_instant_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/instant_apps', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_identity(self, customer_id, **kwargs):  # noqa: E501
        """Deletes an identity from a customer  # noqa: E501

        _in snippets: platform.api.customers.deleteIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_identity(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param CustomerIdentityModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_identity_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_identity_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def delete_identity_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Deletes an identity from a customer  # noqa: E501

        _in snippets: platform.api.customers.deleteIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_identity_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param CustomerIdentityModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_identity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `delete_identity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/identities', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer(self, customer_id, **kwargs):  # noqa: E501
        """Gets the details for a specific customer  # noqa: E501

        _in snippets: platform.api.customers.getCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def get_customer_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Gets the details for a specific customer  # noqa: E501

        _in snippets: platform.api.customers.getCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_customer`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer_by_channel(self, type, key, **kwargs):  # noqa: E501
        """Gets the details for a specific customer based on an the channel type and channel key  # noqa: E501

        _in snippets: platform.api.customers.getCustomerByChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_by_channel(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_by_channel_with_http_info(type, key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_by_channel_with_http_info(type, key, **kwargs)  # noqa: E501
            return data

    def get_customer_by_channel_with_http_info(self, type, key, **kwargs):  # noqa: E501
        """Gets the details for a specific customer based on an the channel type and channel key  # noqa: E501

        _in snippets: platform.api.customers.getCustomerByChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_by_channel_with_http_info(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer_by_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'type' is set
        if ('type' not in params or
                params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_customer_by_channel`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_customer_by_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'type' in params:
            path_params['type'] = params['type']  # noqa: E501
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/channel_types/{type}/channel_keys/{key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer_by_identity(self, type, key, **kwargs):  # noqa: E501
        """Gets the details for a specific customer based on an identity  # noqa: E501

        _in snippets: platform.api.customers.getCustomerByIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_by_identity(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_by_identity_with_http_info(type, key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_by_identity_with_http_info(type, key, **kwargs)  # noqa: E501
            return data

    def get_customer_by_identity_with_http_info(self, type, key, **kwargs):  # noqa: E501
        """Gets the details for a specific customer based on an identity  # noqa: E501

        _in snippets: platform.api.customers.getCustomerByIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_by_identity_with_http_info(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer_by_identity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'type' is set
        if ('type' not in params or
                params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_customer_by_identity`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_customer_by_identity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'type' in params:
            path_params['type'] = params['type']  # noqa: E501
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/identity_types/{type}/identity_keys/{key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer_tags(self, customer_id, **kwargs):  # noqa: E501
        """Gets the tags for a specific customer  # noqa: E501

        _in snippets: platform.api.customers.getCustomerTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_tags(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: list[TagModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def get_customer_tags_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Gets the tags for a specific customer  # noqa: E501

        _in snippets: platform.api.customers.getCustomerTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_tags_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: list[TagModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_customer_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/tags', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TagModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customers(self, **kwargs):  # noqa: E501
        """Gets all the customers in the org ordered by their create date  # noqa: E501

        _in snippets: platform.api.customers.getCustomers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: CustomerModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_customers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_customers_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all the customers in the org ordered by their create date  # noqa: E501

        _in snippets: platform.api.customers.getCustomers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: CustomerModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_instant_apps(self, customer_id, **kwargs):  # noqa: E501
        """Gets all the Instant Apps for the customer  # noqa: E501

        _in snippets: platform.api.customers.getInstantApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_apps(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int first:
        :param int max:
        :param bool desc:
        :return: InstantAppModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_instant_apps_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_instant_apps_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def get_instant_apps_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Gets all the Instant Apps for the customer  # noqa: E501

        _in snippets: platform.api.customers.getInstantApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_apps_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int first:
        :param int max:
        :param bool desc:
        :return: InstantAppModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'first', 'max', 'desc']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instant_apps" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_instant_apps`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501
        if 'desc' in params:
            query_params.append(('desc', params['desc']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/instant_apps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_tag(self, customer_id, tag_name, **kwargs):  # noqa: E501
        """Removes a tag from a customer  # noqa: E501

        _in snippets: platform.api.customers.removeTag_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_tag(customer_id, tag_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param str tag_name: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_tag_with_http_info(customer_id, tag_name, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_tag_with_http_info(customer_id, tag_name, **kwargs)  # noqa: E501
            return data

    def remove_tag_with_http_info(self, customer_id, tag_name, **kwargs):  # noqa: E501
        """Removes a tag from a customer  # noqa: E501

        _in snippets: platform.api.customers.removeTag_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_tag_with_http_info(customer_id, tag_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param str tag_name: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'tag_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `remove_tag`")  # noqa: E501
        # verify the required parameter 'tag_name' is set
        if ('tag_name' not in params or
                params['tag_name'] is None):
            raise ValueError("Missing the required parameter `tag_name` when calling `remove_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501
        if 'tag_name' in params:
            path_params['tagName'] = params['tag_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/tags/{tagName}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_tags(self, customer_id, **kwargs):  # noqa: E501
        """Removes all tags from a customer  # noqa: E501

        _in snippets: platform.api.customers.removeTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_tags(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_tags_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def remove_tags_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Removes all tags from a customer  # noqa: E501

        _in snippets: platform.api.customers.removeTags_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_tags_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `remove_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/tags', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_customer(self, customer_id, **kwargs):  # noqa: E501
        """Updates a customer  # noqa: E501

        _in snippets: platform.api.customers.updateCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_customer(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param UpdateCustomerRequestModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def update_customer_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Updates a customer  # noqa: E501

        _in snippets: platform.api.customers.updateCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_customer_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param UpdateCustomerRequestModel body:
        :return: CustomerModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `update_customer`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_customer_location(self, customer_id, **kwargs):  # noqa: E501
        """Updates a customers location  # noqa: E501

        _in snippets: platform.api.customers.updateCustomerLocation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_customer_location(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param LocationModel body:
        :return: UserLocationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_customer_location_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_customer_location_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def update_customer_location_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Updates a customers location  # noqa: E501

        _in snippets: platform.api.customers.updateCustomerLocation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_customer_location_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param LocationModel body:
        :return: UserLocationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_customer_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `update_customer_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/customers/{customerId}/location', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserLocationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.group_members_api import GroupMembersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestGroupMembersApi(unittest.TestCase):
    """GroupMembersApi unit test stubs"""

    def setUp(self):
        self.api = GroupMembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_group_member(self):
        """Test case for add_group_member

        Add a member to a group  # noqa: E501
        """
        pass

    def test_delete_group_member(self):
        """Test case for delete_group_member

        Delete a member from a group  # noqa: E501
        """
        pass

    def test_get_group_members(self):
        """Test case for get_group_members

        Gets all the members of a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChannelIdModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_name': 'str',
        'org_phone_number': 'str',
        'customer_phone_number': 'str',
        'timestamps': 'list[int]'
    }

    attribute_map = {
        'org_name': 'orgName',
        'org_phone_number': 'orgPhoneNumber',
        'customer_phone_number': 'customerPhoneNumber',
        'timestamps': 'timestamps'
    }

    def __init__(self, org_name=None, org_phone_number=None, customer_phone_number=None, timestamps=None):  # noqa: E501
        """ChannelIdModel - a model defined in Swagger"""  # noqa: E501
        self._org_name = None
        self._org_phone_number = None
        self._customer_phone_number = None
        self._timestamps = None
        self.discriminator = None
        if org_name is not None:
            self.org_name = org_name
        if org_phone_number is not None:
            self.org_phone_number = org_phone_number
        if customer_phone_number is not None:
            self.customer_phone_number = customer_phone_number
        if timestamps is not None:
            self.timestamps = timestamps

    @property
    def org_name(self):
        """Gets the org_name of this ChannelIdModel.  # noqa: E501


        :return: The org_name of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this ChannelIdModel.


        :param org_name: The org_name of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    @property
    def org_phone_number(self):
        """Gets the org_phone_number of this ChannelIdModel.  # noqa: E501


        :return: The org_phone_number of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._org_phone_number

    @org_phone_number.setter
    def org_phone_number(self, org_phone_number):
        """Sets the org_phone_number of this ChannelIdModel.


        :param org_phone_number: The org_phone_number of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._org_phone_number = org_phone_number

    @property
    def customer_phone_number(self):
        """Gets the customer_phone_number of this ChannelIdModel.  # noqa: E501


        :return: The customer_phone_number of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_phone_number

    @customer_phone_number.setter
    def customer_phone_number(self, customer_phone_number):
        """Sets the customer_phone_number of this ChannelIdModel.


        :param customer_phone_number: The customer_phone_number of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._customer_phone_number = customer_phone_number

    @property
    def timestamps(self):
        """Gets the timestamps of this ChannelIdModel.  # noqa: E501


        :return: The timestamps of this ChannelIdModel.  # noqa: E501
        :rtype: list[int]
        """
        return self._timestamps

    @timestamps.setter
    def timestamps(self, timestamps):
        """Sets the timestamps of this ChannelIdModel.


        :param timestamps: The timestamps of this ChannelIdModel.  # noqa: E501
        :type: list[int]
        """

        self._timestamps = timestamps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChannelIdModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelIdModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.instant_apps_api import InstantAppsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestInstantAppsApi(unittest.TestCase):
    """InstantAppsApi unit test stubs"""

    def setUp(self):
        self.api = InstantAppsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_audit_message(self):
        """Test case for add_audit_message

        Add a new audit message  # noqa: E501
        """
        pass

    def test_cancel_timers(self):
        """Test case for cancel_timers

        Cancels any outstanding timers matching the params  # noqa: E501
        """
        pass

    def test_get_audit_messages(self):
        """Test case for get_audit_messages

        Gets the audit trail messages of an Instant App  # noqa: E501
        """
        pass

    def test_get_data1(self):
        """Test case for get_data1

        Gets the value for every element of the Instant App  # noqa: E501
        """
        pass

    def test_get_instant_app(self):
        """Test case for get_instant_app

        Gets the details of a specific Instant App  # noqa: E501
        """
        pass

    def test_is_instant_app_locked(self):
        """Test case for is_instant_app_locked

        Gets the lock status of an Instant App  # noqa: E501
        """
        pass

    def test_save_data(self):
        """Test case for save_data

        Updates the value for every element of the Instant App given  # noqa: E501
        """
        pass

    def test_set_icon(self):
        """Test case for set_icon

        Updates the icon and icon label for an instant app  # noqa: E501
        """
        pass

    def test_set_instant_app_locked(self):
        """Test case for set_instant_app_locked

        Set whether an Instant App is locked  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PoolChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'value': 'str',
        'provider': 'str',
        'created_timestamp': 'int',
        'status': 'str',
        'status_timestamp': 'int'
    }

    attribute_map = {
        'id': 'id',
        'value': 'value',
        'provider': 'provider',
        'created_timestamp': 'createdTimestamp',
        'status': 'status',
        'status_timestamp': 'statusTimestamp'
    }

    def __init__(self, id=None, value=None, provider=None, created_timestamp=None, status=None, status_timestamp=None):  # noqa: E501
        """PoolChannelModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._value = None
        self._provider = None
        self._created_timestamp = None
        self._status = None
        self._status_timestamp = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if value is not None:
            self.value = value
        if provider is not None:
            self.provider = provider
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if status is not None:
            self.status = status
        if status_timestamp is not None:
            self.status_timestamp = status_timestamp

    @property
    def id(self):
        """Gets the id of this PoolChannelModel.  # noqa: E501

        The system generated unique id for this channel.  # noqa: E501

        :return: The id of this PoolChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PoolChannelModel.

        The system generated unique id for this channel.  # noqa: E501

        :param id: The id of this PoolChannelModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def value(self):
        """Gets the value of this PoolChannelModel.  # noqa: E501

        The value used to identify the channel. For SMS channels, this is a phone number  # noqa: E501

        :return: The value of this PoolChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PoolChannelModel.

        The value used to identify the channel. For SMS channels, this is a phone number  # noqa: E501

        :param value: The value of this PoolChannelModel.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def provider(self):
        """Gets the provider of this PoolChannelModel.  # noqa: E501

        Provider of the channel  # noqa: E501

        :return: The provider of this PoolChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this PoolChannelModel.

        Provider of the channel  # noqa: E501

        :param provider: The provider of this PoolChannelModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TWILIO", "YTEL", "BANDWIDTH"]  # noqa: E501
        if provider not in allowed_values:
            raise ValueError(
                "Invalid value for `provider` ({0}), must be one of {1}"  # noqa: E501
                .format(provider, allowed_values)
            )

        self._provider = provider

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this PoolChannelModel.  # noqa: E501

        Time that the channel was added to the pool  # noqa: E501

        :return: The created_timestamp of this PoolChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this PoolChannelModel.

        Time that the channel was added to the pool  # noqa: E501

        :param created_timestamp: The created_timestamp of this PoolChannelModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def status(self):
        """Gets the status of this PoolChannelModel.  # noqa: E501

        Status of the channel in the pool  # noqa: E501

        :return: The status of this PoolChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PoolChannelModel.

        Status of the channel in the pool  # noqa: E501

        :param status: The status of this PoolChannelModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "PAUSED", "DECOMISSIONING", "DELETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def status_timestamp(self):
        """Gets the status_timestamp of this PoolChannelModel.  # noqa: E501

        Last time the status was updated  # noqa: E501

        :return: The status_timestamp of this PoolChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._status_timestamp

    @status_timestamp.setter
    def status_timestamp(self, status_timestamp):
        """Sets the status_timestamp of this PoolChannelModel.

        Last time the status was updated  # noqa: E501

        :param status_timestamp: The status_timestamp of this PoolChannelModel.  # noqa: E501
        :type: int
        """

        self._status_timestamp = status_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PoolChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoolChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.event_endpoints_api import EventEndpointsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestEventEndpointsApi(unittest.TestCase):
    """EventEndpointsApi unit test stubs"""

    def setUp(self):
        self.api = EventEndpointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_event_endpoint(self):
        """Test case for add_event_endpoint

        Creates an Event Endpoint  # noqa: E501
        """
        pass

    def test_delete_event_endpoint(self):
        """Test case for delete_event_endpoint

        Deletes an Event Endpoint  # noqa: E501
        """
        pass

    def test_get_event_endpoint(self):
        """Test case for get_event_endpoint

        Gets a specific Event Endpoint  # noqa: E501
        """
        pass

    def test_get_event_endpoints(self):
        """Test case for get_event_endpoints

        Gets all Event Endpoints  # noqa: E501
        """
        pass

    def test_reset_secret(self):
        """Test case for reset_secret

        Resets the secret for an Event Endpoint  # noqa: E501
        """
        pass

    def test_update_event_endpoint(self):
        """Test case for update_event_endpoint

        Updates an Event Endpoint  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ScheduledActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'user_id': 'int',
        'org_channel': 'OrgChannelModel',
        'customer_channel': 'CustomerChannelModel',
        'created_timestamp': 'int',
        'fulfillment': 'ScheduledActionFulfillmentModel',
        'status': 'str',
        'deliver_on': 'int'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'org_channel': 'orgChannel',
        'customer_channel': 'customerChannel',
        'created_timestamp': 'createdTimestamp',
        'fulfillment': 'fulfillment',
        'status': 'status',
        'deliver_on': 'deliverOn'
    }

    def __init__(self, id=None, user_id=None, org_channel=None, customer_channel=None, created_timestamp=None, fulfillment=None, status=None, deliver_on=None):  # noqa: E501
        """ScheduledActionModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._user_id = None
        self._org_channel = None
        self._customer_channel = None
        self._created_timestamp = None
        self._fulfillment = None
        self._status = None
        self._deliver_on = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if org_channel is not None:
            self.org_channel = org_channel
        if customer_channel is not None:
            self.customer_channel = customer_channel
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if fulfillment is not None:
            self.fulfillment = fulfillment
        if status is not None:
            self.status = status
        if deliver_on is not None:
            self.deliver_on = deliver_on

    @property
    def id(self):
        """Gets the id of this ScheduledActionModel.  # noqa: E501

        The system generated unique id for this Scheduled Action.  # noqa: E501

        :return: The id of this ScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScheduledActionModel.

        The system generated unique id for this Scheduled Action.  # noqa: E501

        :param id: The id of this ScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this ScheduledActionModel.  # noqa: E501

        ID of the user that will deliver the Scheduled Action.  # noqa: E501

        :return: The user_id of this ScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ScheduledActionModel.

        ID of the user that will deliver the Scheduled Action.  # noqa: E501

        :param user_id: The user_id of this ScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def org_channel(self):
        """Gets the org_channel of this ScheduledActionModel.  # noqa: E501


        :return: The org_channel of this ScheduledActionModel.  # noqa: E501
        :rtype: OrgChannelModel
        """
        return self._org_channel

    @org_channel.setter
    def org_channel(self, org_channel):
        """Sets the org_channel of this ScheduledActionModel.


        :param org_channel: The org_channel of this ScheduledActionModel.  # noqa: E501
        :type: OrgChannelModel
        """

        self._org_channel = org_channel

    @property
    def customer_channel(self):
        """Gets the customer_channel of this ScheduledActionModel.  # noqa: E501


        :return: The customer_channel of this ScheduledActionModel.  # noqa: E501
        :rtype: CustomerChannelModel
        """
        return self._customer_channel

    @customer_channel.setter
    def customer_channel(self, customer_channel):
        """Sets the customer_channel of this ScheduledActionModel.


        :param customer_channel: The customer_channel of this ScheduledActionModel.  # noqa: E501
        :type: CustomerChannelModel
        """

        self._customer_channel = customer_channel

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this ScheduledActionModel.  # noqa: E501

        The time the Scheduled Action was created.  # noqa: E501

        :return: The created_timestamp of this ScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this ScheduledActionModel.

        The time the Scheduled Action was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this ScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def fulfillment(self):
        """Gets the fulfillment of this ScheduledActionModel.  # noqa: E501


        :return: The fulfillment of this ScheduledActionModel.  # noqa: E501
        :rtype: ScheduledActionFulfillmentModel
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this ScheduledActionModel.


        :param fulfillment: The fulfillment of this ScheduledActionModel.  # noqa: E501
        :type: ScheduledActionFulfillmentModel
        """

        self._fulfillment = fulfillment

    @property
    def status(self):
        """Gets the status of this ScheduledActionModel.  # noqa: E501

        Status of the Scheduled Action.  # noqa: E501

        :return: The status of this ScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ScheduledActionModel.

        Status of the Scheduled Action.  # noqa: E501

        :param status: The status of this ScheduledActionModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SCHEDULED", "ABORTED", "COMPLETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def deliver_on(self):
        """Gets the deliver_on of this ScheduledActionModel.  # noqa: E501

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :return: The deliver_on of this ScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._deliver_on

    @deliver_on.setter
    def deliver_on(self, deliver_on):
        """Sets the deliver_on of this ScheduledActionModel.

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :param deliver_on: The deliver_on of this ScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._deliver_on = deliver_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScheduledActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IntegrationRequestModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'api_id': 'str',
        'active': 'bool',
        'type': 'str',
        'twilio_model': 'TwilioIntegrationModel',
        'salesforce_model': 'SalesforceIntegrationRequestModel',
        'google_map_model': 'GoogleMapIntegrationModel'
    }

    attribute_map = {
        'name': 'name',
        'api_id': 'apiId',
        'active': 'active',
        'type': 'type',
        'twilio_model': 'twilioModel',
        'salesforce_model': 'salesforceModel',
        'google_map_model': 'googleMapModel'
    }

    def __init__(self, name=None, api_id=None, active=None, type=None, twilio_model=None, salesforce_model=None, google_map_model=None):  # noqa: E501
        """IntegrationRequestModel - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._api_id = None
        self._active = None
        self._type = None
        self._twilio_model = None
        self._salesforce_model = None
        self._google_map_model = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if api_id is not None:
            self.api_id = api_id
        if active is not None:
            self.active = active
        if type is not None:
            self.type = type
        if twilio_model is not None:
            self.twilio_model = twilio_model
        if salesforce_model is not None:
            self.salesforce_model = salesforce_model
        if google_map_model is not None:
            self.google_map_model = google_map_model

    @property
    def name(self):
        """Gets the name of this IntegrationRequestModel.  # noqa: E501

        A descriptive name for this integration to show in agent UIs.  # noqa: E501

        :return: The name of this IntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IntegrationRequestModel.

        A descriptive name for this integration to show in agent UIs.  # noqa: E501

        :param name: The name of this IntegrationRequestModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_id(self):
        """Gets the api_id of this IntegrationRequestModel.  # noqa: E501

        The programmatic, unique id of this integration.  # noqa: E501

        :return: The api_id of this IntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._api_id

    @api_id.setter
    def api_id(self, api_id):
        """Sets the api_id of this IntegrationRequestModel.

        The programmatic, unique id of this integration.  # noqa: E501

        :param api_id: The api_id of this IntegrationRequestModel.  # noqa: E501
        :type: str
        """

        self._api_id = api_id

    @property
    def active(self):
        """Gets the active of this IntegrationRequestModel.  # noqa: E501

        Whether the integration is active.  # noqa: E501

        :return: The active of this IntegrationRequestModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this IntegrationRequestModel.

        Whether the integration is active.  # noqa: E501

        :param active: The active of this IntegrationRequestModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def type(self):
        """Gets the type of this IntegrationRequestModel.  # noqa: E501

        Type of the integration  # noqa: E501

        :return: The type of this IntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IntegrationRequestModel.

        Type of the integration  # noqa: E501

        :param type: The type of this IntegrationRequestModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TWILIO", "SLACK", "GOOGLE_SHEETS", "ALTERRA", "SMOOCH", "YGL", "SALESFORCE", "GOOGLE_MAPS", "OKTA", "YTEL", "CHANNEL_VERIFY", "NATION_BUILDER", "LINE", "GOOGLE_CALENDAR", "BANDWIDTH", "BLACKBAUD", "NGP_VAN", "MANAGED_SIGNAL_WIRE", "SIGNAL_WIRE", "MANAGED_BANDWIDTH"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def twilio_model(self):
        """Gets the twilio_model of this IntegrationRequestModel.  # noqa: E501


        :return: The twilio_model of this IntegrationRequestModel.  # noqa: E501
        :rtype: TwilioIntegrationModel
        """
        return self._twilio_model

    @twilio_model.setter
    def twilio_model(self, twilio_model):
        """Sets the twilio_model of this IntegrationRequestModel.


        :param twilio_model: The twilio_model of this IntegrationRequestModel.  # noqa: E501
        :type: TwilioIntegrationModel
        """

        self._twilio_model = twilio_model

    @property
    def salesforce_model(self):
        """Gets the salesforce_model of this IntegrationRequestModel.  # noqa: E501


        :return: The salesforce_model of this IntegrationRequestModel.  # noqa: E501
        :rtype: SalesforceIntegrationRequestModel
        """
        return self._salesforce_model

    @salesforce_model.setter
    def salesforce_model(self, salesforce_model):
        """Sets the salesforce_model of this IntegrationRequestModel.


        :param salesforce_model: The salesforce_model of this IntegrationRequestModel.  # noqa: E501
        :type: SalesforceIntegrationRequestModel
        """

        self._salesforce_model = salesforce_model

    @property
    def google_map_model(self):
        """Gets the google_map_model of this IntegrationRequestModel.  # noqa: E501


        :return: The google_map_model of this IntegrationRequestModel.  # noqa: E501
        :rtype: GoogleMapIntegrationModel
        """
        return self._google_map_model

    @google_map_model.setter
    def google_map_model(self, google_map_model):
        """Sets the google_map_model of this IntegrationRequestModel.


        :param google_map_model: The google_map_model of this IntegrationRequestModel.  # noqa: E501
        :type: GoogleMapIntegrationModel
        """

        self._google_map_model = google_map_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationRequestModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationRequestModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsBulkActionReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'actions_total': 'int',
        'actions_manual': 'int',
        'actions_auto': 'int',
        'contacts_targeted_manual': 'int',
        'contacts_targeted_auto': 'int',
        'contacts_processed_manual': 'int',
        'contacts_processed_auto': 'int',
        'contacts_errored_manual': 'int',
        'contacts_errored_auto': 'int',
        'contacts_resolved_manual': 'int',
        'contacts_resolved_auto': 'int',
        'outgoing_messages_manual': 'int',
        'outgoing_messages_auto': 'int',
        'outgoing_segments_manual': 'int',
        'outgoing_segments_auto': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'actions_total': 'actionsTotal',
        'actions_manual': 'actionsManual',
        'actions_auto': 'actionsAuto',
        'contacts_targeted_manual': 'contactsTargetedManual',
        'contacts_targeted_auto': 'contactsTargetedAuto',
        'contacts_processed_manual': 'contactsProcessedManual',
        'contacts_processed_auto': 'contactsProcessedAuto',
        'contacts_errored_manual': 'contactsErroredManual',
        'contacts_errored_auto': 'contactsErroredAuto',
        'contacts_resolved_manual': 'contactsResolvedManual',
        'contacts_resolved_auto': 'contactsResolvedAuto',
        'outgoing_messages_manual': 'outgoingMessagesManual',
        'outgoing_messages_auto': 'outgoingMessagesAuto',
        'outgoing_segments_manual': 'outgoingSegmentsManual',
        'outgoing_segments_auto': 'outgoingSegmentsAuto'
    }

    def __init__(self, timestamp_epoch=None, actions_total=None, actions_manual=None, actions_auto=None, contacts_targeted_manual=None, contacts_targeted_auto=None, contacts_processed_manual=None, contacts_processed_auto=None, contacts_errored_manual=None, contacts_errored_auto=None, contacts_resolved_manual=None, contacts_resolved_auto=None, outgoing_messages_manual=None, outgoing_messages_auto=None, outgoing_segments_manual=None, outgoing_segments_auto=None):  # noqa: E501
        """AnalyticsBulkActionReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._actions_total = None
        self._actions_manual = None
        self._actions_auto = None
        self._contacts_targeted_manual = None
        self._contacts_targeted_auto = None
        self._contacts_processed_manual = None
        self._contacts_processed_auto = None
        self._contacts_errored_manual = None
        self._contacts_errored_auto = None
        self._contacts_resolved_manual = None
        self._contacts_resolved_auto = None
        self._outgoing_messages_manual = None
        self._outgoing_messages_auto = None
        self._outgoing_segments_manual = None
        self._outgoing_segments_auto = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if actions_total is not None:
            self.actions_total = actions_total
        if actions_manual is not None:
            self.actions_manual = actions_manual
        if actions_auto is not None:
            self.actions_auto = actions_auto
        if contacts_targeted_manual is not None:
            self.contacts_targeted_manual = contacts_targeted_manual
        if contacts_targeted_auto is not None:
            self.contacts_targeted_auto = contacts_targeted_auto
        if contacts_processed_manual is not None:
            self.contacts_processed_manual = contacts_processed_manual
        if contacts_processed_auto is not None:
            self.contacts_processed_auto = contacts_processed_auto
        if contacts_errored_manual is not None:
            self.contacts_errored_manual = contacts_errored_manual
        if contacts_errored_auto is not None:
            self.contacts_errored_auto = contacts_errored_auto
        if contacts_resolved_manual is not None:
            self.contacts_resolved_manual = contacts_resolved_manual
        if contacts_resolved_auto is not None:
            self.contacts_resolved_auto = contacts_resolved_auto
        if outgoing_messages_manual is not None:
            self.outgoing_messages_manual = outgoing_messages_manual
        if outgoing_messages_auto is not None:
            self.outgoing_messages_auto = outgoing_messages_auto
        if outgoing_segments_manual is not None:
            self.outgoing_segments_manual = outgoing_segments_manual
        if outgoing_segments_auto is not None:
            self.outgoing_segments_auto = outgoing_segments_auto

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsBulkActionReportModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsBulkActionReportModel.

        The timestamp at the start of the default group-by window as a Unix timestamp  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def actions_total(self):
        """Gets the actions_total of this AnalyticsBulkActionReportModel.  # noqa: E501

        The total number of Actions Created during the default group-by window.  # noqa: E501

        :return: The actions_total of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._actions_total

    @actions_total.setter
    def actions_total(self, actions_total):
        """Sets the actions_total of this AnalyticsBulkActionReportModel.

        The total number of Actions Created during the default group-by window.  # noqa: E501

        :param actions_total: The actions_total of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._actions_total = actions_total

    @property
    def actions_manual(self):
        """Gets the actions_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Manual (P2P) Actions created during the default group-by window.  # noqa: E501

        :return: The actions_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._actions_manual

    @actions_manual.setter
    def actions_manual(self, actions_manual):
        """Sets the actions_manual of this AnalyticsBulkActionReportModel.

        The number of Manual (P2P) Actions created during the default group-by window.  # noqa: E501

        :param actions_manual: The actions_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._actions_manual = actions_manual

    @property
    def actions_auto(self):
        """Gets the actions_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Automatic (A2P) Actions created during the default group-by window.  # noqa: E501

        :return: The actions_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._actions_auto

    @actions_auto.setter
    def actions_auto(self, actions_auto):
        """Sets the actions_auto of this AnalyticsBulkActionReportModel.

        The number of Automatic (A2P) Actions created during the default group-by window.  # noqa: E501

        :param actions_auto: The actions_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._actions_auto = actions_auto

    @property
    def contacts_targeted_manual(self):
        """Gets the contacts_targeted_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Manual (P2P) Contacts targeted during the default group-by window.  # noqa: E501

        :return: The contacts_targeted_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_targeted_manual

    @contacts_targeted_manual.setter
    def contacts_targeted_manual(self, contacts_targeted_manual):
        """Sets the contacts_targeted_manual of this AnalyticsBulkActionReportModel.

        The number of Manual (P2P) Contacts targeted during the default group-by window.  # noqa: E501

        :param contacts_targeted_manual: The contacts_targeted_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_targeted_manual = contacts_targeted_manual

    @property
    def contacts_targeted_auto(self):
        """Gets the contacts_targeted_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Automatic (A2P) Contacts targeted during the default group-by window.  # noqa: E501

        :return: The contacts_targeted_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_targeted_auto

    @contacts_targeted_auto.setter
    def contacts_targeted_auto(self, contacts_targeted_auto):
        """Sets the contacts_targeted_auto of this AnalyticsBulkActionReportModel.

        The number of Automatic (A2P) Contacts targeted during the default group-by window.  # noqa: E501

        :param contacts_targeted_auto: The contacts_targeted_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_targeted_auto = contacts_targeted_auto

    @property
    def contacts_processed_manual(self):
        """Gets the contacts_processed_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Manual (P2P) Contacts processed during the default group-by window.  # noqa: E501

        :return: The contacts_processed_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_processed_manual

    @contacts_processed_manual.setter
    def contacts_processed_manual(self, contacts_processed_manual):
        """Sets the contacts_processed_manual of this AnalyticsBulkActionReportModel.

        The number of Manual (P2P) Contacts processed during the default group-by window.  # noqa: E501

        :param contacts_processed_manual: The contacts_processed_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_processed_manual = contacts_processed_manual

    @property
    def contacts_processed_auto(self):
        """Gets the contacts_processed_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Automatic (A2P) Contacts processed during the default group-by window.  # noqa: E501

        :return: The contacts_processed_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_processed_auto

    @contacts_processed_auto.setter
    def contacts_processed_auto(self, contacts_processed_auto):
        """Sets the contacts_processed_auto of this AnalyticsBulkActionReportModel.

        The number of Automatic (A2P) Contacts processed during the default group-by window.  # noqa: E501

        :param contacts_processed_auto: The contacts_processed_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_processed_auto = contacts_processed_auto

    @property
    def contacts_errored_manual(self):
        """Gets the contacts_errored_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Manual (P2P) Contacts errored during the default group-by window.  # noqa: E501

        :return: The contacts_errored_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_errored_manual

    @contacts_errored_manual.setter
    def contacts_errored_manual(self, contacts_errored_manual):
        """Sets the contacts_errored_manual of this AnalyticsBulkActionReportModel.

        The number of Manual (P2P) Contacts errored during the default group-by window.  # noqa: E501

        :param contacts_errored_manual: The contacts_errored_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_errored_manual = contacts_errored_manual

    @property
    def contacts_errored_auto(self):
        """Gets the contacts_errored_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Automatic (A2P) Contacts errored during the default group-by window.  # noqa: E501

        :return: The contacts_errored_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_errored_auto

    @contacts_errored_auto.setter
    def contacts_errored_auto(self, contacts_errored_auto):
        """Sets the contacts_errored_auto of this AnalyticsBulkActionReportModel.

        The number of Automatic (A2P) Contacts errored during the default group-by window.  # noqa: E501

        :param contacts_errored_auto: The contacts_errored_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_errored_auto = contacts_errored_auto

    @property
    def contacts_resolved_manual(self):
        """Gets the contacts_resolved_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Manual (P2P) Contacts resolved during the default group-by window.  # noqa: E501

        :return: The contacts_resolved_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_resolved_manual

    @contacts_resolved_manual.setter
    def contacts_resolved_manual(self, contacts_resolved_manual):
        """Sets the contacts_resolved_manual of this AnalyticsBulkActionReportModel.

        The number of Manual (P2P) Contacts resolved during the default group-by window.  # noqa: E501

        :param contacts_resolved_manual: The contacts_resolved_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_resolved_manual = contacts_resolved_manual

    @property
    def contacts_resolved_auto(self):
        """Gets the contacts_resolved_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Automatic (A2P) Contacts resolved during the default group-by window.  # noqa: E501

        :return: The contacts_resolved_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contacts_resolved_auto

    @contacts_resolved_auto.setter
    def contacts_resolved_auto(self, contacts_resolved_auto):
        """Sets the contacts_resolved_auto of this AnalyticsBulkActionReportModel.

        The number of Automatic (A2P) Contacts resolved during the default group-by window.  # noqa: E501

        :param contacts_resolved_auto: The contacts_resolved_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._contacts_resolved_auto = contacts_resolved_auto

    @property
    def outgoing_messages_manual(self):
        """Gets the outgoing_messages_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Messages sent to Manual (P2P) Contacts during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_manual

    @outgoing_messages_manual.setter
    def outgoing_messages_manual(self, outgoing_messages_manual):
        """Sets the outgoing_messages_manual of this AnalyticsBulkActionReportModel.

        The number of Messages sent to Manual (P2P) Contacts during the default group-by window.  # noqa: E501

        :param outgoing_messages_manual: The outgoing_messages_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_manual = outgoing_messages_manual

    @property
    def outgoing_messages_auto(self):
        """Gets the outgoing_messages_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Messages sent to Automatic (A2P) Contacts during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_auto

    @outgoing_messages_auto.setter
    def outgoing_messages_auto(self, outgoing_messages_auto):
        """Sets the outgoing_messages_auto of this AnalyticsBulkActionReportModel.

        The number of Messages sent to Automatic (A2P) Contacts during the default group-by window.  # noqa: E501

        :param outgoing_messages_auto: The outgoing_messages_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_auto = outgoing_messages_auto

    @property
    def outgoing_segments_manual(self):
        """Gets the outgoing_segments_manual of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Segments sent to Manual (P2P) Contacts during the default group-by window.  # noqa: E501

        :return: The outgoing_segments_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_segments_manual

    @outgoing_segments_manual.setter
    def outgoing_segments_manual(self, outgoing_segments_manual):
        """Sets the outgoing_segments_manual of this AnalyticsBulkActionReportModel.

        The number of Segments sent to Manual (P2P) Contacts during the default group-by window.  # noqa: E501

        :param outgoing_segments_manual: The outgoing_segments_manual of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_segments_manual = outgoing_segments_manual

    @property
    def outgoing_segments_auto(self):
        """Gets the outgoing_segments_auto of this AnalyticsBulkActionReportModel.  # noqa: E501

        The number of Segments sent to Automatic (A2P) Contacts during the default group-by window.  # noqa: E501

        :return: The outgoing_segments_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_segments_auto

    @outgoing_segments_auto.setter
    def outgoing_segments_auto(self, outgoing_segments_auto):
        """Sets the outgoing_segments_auto of this AnalyticsBulkActionReportModel.

        The number of Segments sent to Automatic (A2P) Contacts during the default group-by window.  # noqa: E501

        :param outgoing_segments_auto: The outgoing_segments_auto of this AnalyticsBulkActionReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_segments_auto = outgoing_segments_auto

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsBulkActionReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsBulkActionReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PresenceSummaryModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'num_team_active': 'int',
        'num_team_idle': 'int',
        'num_customers_active': 'int',
        'num_customers_idle': 'int',
        'num_sessions': 'int'
    }

    attribute_map = {
        'num_team_active': 'numTeamActive',
        'num_team_idle': 'numTeamIdle',
        'num_customers_active': 'numCustomersActive',
        'num_customers_idle': 'numCustomersIdle',
        'num_sessions': 'numSessions'
    }

    def __init__(self, num_team_active=None, num_team_idle=None, num_customers_active=None, num_customers_idle=None, num_sessions=None):  # noqa: E501
        """PresenceSummaryModel - a model defined in Swagger"""  # noqa: E501
        self._num_team_active = None
        self._num_team_idle = None
        self._num_customers_active = None
        self._num_customers_idle = None
        self._num_sessions = None
        self.discriminator = None
        if num_team_active is not None:
            self.num_team_active = num_team_active
        if num_team_idle is not None:
            self.num_team_idle = num_team_idle
        if num_customers_active is not None:
            self.num_customers_active = num_customers_active
        if num_customers_idle is not None:
            self.num_customers_idle = num_customers_idle
        if num_sessions is not None:
            self.num_sessions = num_sessions

    @property
    def num_team_active(self):
        """Gets the num_team_active of this PresenceSummaryModel.  # noqa: E501


        :return: The num_team_active of this PresenceSummaryModel.  # noqa: E501
        :rtype: int
        """
        return self._num_team_active

    @num_team_active.setter
    def num_team_active(self, num_team_active):
        """Sets the num_team_active of this PresenceSummaryModel.


        :param num_team_active: The num_team_active of this PresenceSummaryModel.  # noqa: E501
        :type: int
        """

        self._num_team_active = num_team_active

    @property
    def num_team_idle(self):
        """Gets the num_team_idle of this PresenceSummaryModel.  # noqa: E501


        :return: The num_team_idle of this PresenceSummaryModel.  # noqa: E501
        :rtype: int
        """
        return self._num_team_idle

    @num_team_idle.setter
    def num_team_idle(self, num_team_idle):
        """Sets the num_team_idle of this PresenceSummaryModel.


        :param num_team_idle: The num_team_idle of this PresenceSummaryModel.  # noqa: E501
        :type: int
        """

        self._num_team_idle = num_team_idle

    @property
    def num_customers_active(self):
        """Gets the num_customers_active of this PresenceSummaryModel.  # noqa: E501


        :return: The num_customers_active of this PresenceSummaryModel.  # noqa: E501
        :rtype: int
        """
        return self._num_customers_active

    @num_customers_active.setter
    def num_customers_active(self, num_customers_active):
        """Sets the num_customers_active of this PresenceSummaryModel.


        :param num_customers_active: The num_customers_active of this PresenceSummaryModel.  # noqa: E501
        :type: int
        """

        self._num_customers_active = num_customers_active

    @property
    def num_customers_idle(self):
        """Gets the num_customers_idle of this PresenceSummaryModel.  # noqa: E501


        :return: The num_customers_idle of this PresenceSummaryModel.  # noqa: E501
        :rtype: int
        """
        return self._num_customers_idle

    @num_customers_idle.setter
    def num_customers_idle(self, num_customers_idle):
        """Sets the num_customers_idle of this PresenceSummaryModel.


        :param num_customers_idle: The num_customers_idle of this PresenceSummaryModel.  # noqa: E501
        :type: int
        """

        self._num_customers_idle = num_customers_idle

    @property
    def num_sessions(self):
        """Gets the num_sessions of this PresenceSummaryModel.  # noqa: E501


        :return: The num_sessions of this PresenceSummaryModel.  # noqa: E501
        :rtype: int
        """
        return self._num_sessions

    @num_sessions.setter
    def num_sessions(self, num_sessions):
        """Sets the num_sessions of this PresenceSummaryModel.


        :param num_sessions: The num_sessions of this PresenceSummaryModel.  # noqa: E501
        :type: int
        """

        self._num_sessions = num_sessions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PresenceSummaryModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PresenceSummaryModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MessagesSendFileToCustomerBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_channel_id': 'str',
        'customer_channel_key': 'str',
        'customer_channel_id': 'int',
        'message': 'str',
        'ignore_delivery_restrictions': 'bool',
        'file': 'str'
    }

    attribute_map = {
        'org_channel_id': 'orgChannelId',
        'customer_channel_key': 'customerChannelKey',
        'customer_channel_id': 'customerChannelId',
        'message': 'message',
        'ignore_delivery_restrictions': 'ignoreDeliveryRestrictions',
        'file': 'file'
    }

    def __init__(self, org_channel_id=None, customer_channel_key=None, customer_channel_id=None, message=None, ignore_delivery_restrictions=None, file=None):  # noqa: E501
        """MessagesSendFileToCustomerBody - a model defined in Swagger"""  # noqa: E501
        self._org_channel_id = None
        self._customer_channel_key = None
        self._customer_channel_id = None
        self._message = None
        self._ignore_delivery_restrictions = None
        self._file = None
        self.discriminator = None
        self.org_channel_id = org_channel_id
        if customer_channel_key is not None:
            self.customer_channel_key = customer_channel_key
        if customer_channel_id is not None:
            self.customer_channel_id = customer_channel_id
        if message is not None:
            self.message = message
        if ignore_delivery_restrictions is not None:
            self.ignore_delivery_restrictions = ignore_delivery_restrictions
        self.file = file

    @property
    def org_channel_id(self):
        """Gets the org_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501

        The org channel apiId (or internal id) of the sending channel  # noqa: E501

        :return: The org_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_id

    @org_channel_id.setter
    def org_channel_id(self, org_channel_id):
        """Sets the org_channel_id of this MessagesSendFileToCustomerBody.

        The org channel apiId (or internal id) of the sending channel  # noqa: E501

        :param org_channel_id: The org_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: str
        """
        if org_channel_id is None:
            raise ValueError("Invalid value for `org_channel_id`, must not be `None`")  # noqa: E501

        self._org_channel_id = org_channel_id

    @property
    def customer_channel_key(self):
        """Gets the customer_channel_key of this MessagesSendFileToCustomerBody.  # noqa: E501

        The key of the customer channel, for instance, the customer phone number to SMS to.  Must supply this or customerChannelId  # noqa: E501

        :return: The customer_channel_key of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: str
        """
        return self._customer_channel_key

    @customer_channel_key.setter
    def customer_channel_key(self, customer_channel_key):
        """Sets the customer_channel_key of this MessagesSendFileToCustomerBody.

        The key of the customer channel, for instance, the customer phone number to SMS to.  Must supply this or customerChannelId  # noqa: E501

        :param customer_channel_key: The customer_channel_key of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: str
        """

        self._customer_channel_key = customer_channel_key

    @property
    def customer_channel_id(self):
        """Gets the customer_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501

        The internal id of the customer channel key. Must supply this or the customerChannelKey  # noqa: E501

        :return: The customer_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: int
        """
        return self._customer_channel_id

    @customer_channel_id.setter
    def customer_channel_id(self, customer_channel_id):
        """Sets the customer_channel_id of this MessagesSendFileToCustomerBody.

        The internal id of the customer channel key. Must supply this or the customerChannelKey  # noqa: E501

        :param customer_channel_id: The customer_channel_id of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: int
        """

        self._customer_channel_id = customer_channel_id

    @property
    def message(self):
        """Gets the message of this MessagesSendFileToCustomerBody.  # noqa: E501

        Optional message to include with the file  # noqa: E501

        :return: The message of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this MessagesSendFileToCustomerBody.

        Optional message to include with the file  # noqa: E501

        :param message: The message of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def ignore_delivery_restrictions(self):
        """Gets the ignore_delivery_restrictions of this MessagesSendFileToCustomerBody.  # noqa: E501

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :return: The ignore_delivery_restrictions of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_delivery_restrictions

    @ignore_delivery_restrictions.setter
    def ignore_delivery_restrictions(self, ignore_delivery_restrictions):
        """Sets the ignore_delivery_restrictions of this MessagesSendFileToCustomerBody.

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :param ignore_delivery_restrictions: The ignore_delivery_restrictions of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: bool
        """

        self._ignore_delivery_restrictions = ignore_delivery_restrictions

    @property
    def file(self):
        """Gets the file of this MessagesSendFileToCustomerBody.  # noqa: E501

        The file to send to the user.  # noqa: E501

        :return: The file of this MessagesSendFileToCustomerBody.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this MessagesSendFileToCustomerBody.

        The file to send to the user.  # noqa: E501

        :param file: The file of this MessagesSendFileToCustomerBody.  # noqa: E501
        :type: str
        """
        if file is None:
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessagesSendFileToCustomerBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessagesSendFileToCustomerBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SmoochChatOrgChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'smooch_app_id': 'str',
        'smooch_integration_id': 'str',
        'app_key_id': 'str',
        'app_key_secret': 'str',
        'ignore_js_customer_info': 'bool'
    }

    attribute_map = {
        'smooch_app_id': 'smoochAppId',
        'smooch_integration_id': 'smoochIntegrationId',
        'app_key_id': 'appKeyId',
        'app_key_secret': 'appKeySecret',
        'ignore_js_customer_info': 'ignoreJsCustomerInfo'
    }

    def __init__(self, smooch_app_id=None, smooch_integration_id=None, app_key_id=None, app_key_secret=None, ignore_js_customer_info=None):  # noqa: E501
        """SmoochChatOrgChannelModel - a model defined in Swagger"""  # noqa: E501
        self._smooch_app_id = None
        self._smooch_integration_id = None
        self._app_key_id = None
        self._app_key_secret = None
        self._ignore_js_customer_info = None
        self.discriminator = None
        if smooch_app_id is not None:
            self.smooch_app_id = smooch_app_id
        if smooch_integration_id is not None:
            self.smooch_integration_id = smooch_integration_id
        if app_key_id is not None:
            self.app_key_id = app_key_id
        if app_key_secret is not None:
            self.app_key_secret = app_key_secret
        if ignore_js_customer_info is not None:
            self.ignore_js_customer_info = ignore_js_customer_info

    @property
    def smooch_app_id(self):
        """Gets the smooch_app_id of this SmoochChatOrgChannelModel.  # noqa: E501

        The App Id from Smooch.  # noqa: E501

        :return: The smooch_app_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._smooch_app_id

    @smooch_app_id.setter
    def smooch_app_id(self, smooch_app_id):
        """Sets the smooch_app_id of this SmoochChatOrgChannelModel.

        The App Id from Smooch.  # noqa: E501

        :param smooch_app_id: The smooch_app_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._smooch_app_id = smooch_app_id

    @property
    def smooch_integration_id(self):
        """Gets the smooch_integration_id of this SmoochChatOrgChannelModel.  # noqa: E501

        The Web Integration Id from Smooch.  # noqa: E501

        :return: The smooch_integration_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._smooch_integration_id

    @smooch_integration_id.setter
    def smooch_integration_id(self, smooch_integration_id):
        """Sets the smooch_integration_id of this SmoochChatOrgChannelModel.

        The Web Integration Id from Smooch.  # noqa: E501

        :param smooch_integration_id: The smooch_integration_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._smooch_integration_id = smooch_integration_id

    @property
    def app_key_id(self):
        """Gets the app_key_id of this SmoochChatOrgChannelModel.  # noqa: E501

        The Key Id for the Smooch app.  # noqa: E501

        :return: The app_key_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._app_key_id

    @app_key_id.setter
    def app_key_id(self, app_key_id):
        """Sets the app_key_id of this SmoochChatOrgChannelModel.

        The Key Id for the Smooch app.  # noqa: E501

        :param app_key_id: The app_key_id of this SmoochChatOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._app_key_id = app_key_id

    @property
    def app_key_secret(self):
        """Gets the app_key_secret of this SmoochChatOrgChannelModel.  # noqa: E501

        The Key Secret for the Smooch app.  # noqa: E501

        :return: The app_key_secret of this SmoochChatOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._app_key_secret

    @app_key_secret.setter
    def app_key_secret(self, app_key_secret):
        """Sets the app_key_secret of this SmoochChatOrgChannelModel.

        The Key Secret for the Smooch app.  # noqa: E501

        :param app_key_secret: The app_key_secret of this SmoochChatOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._app_key_secret = app_key_secret

    @property
    def ignore_js_customer_info(self):
        """Gets the ignore_js_customer_info of this SmoochChatOrgChannelModel.  # noqa: E501

        Whether the insecure customer name and email passed from Javascript should be ignored.  # noqa: E501

        :return: The ignore_js_customer_info of this SmoochChatOrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_js_customer_info

    @ignore_js_customer_info.setter
    def ignore_js_customer_info(self, ignore_js_customer_info):
        """Sets the ignore_js_customer_info of this SmoochChatOrgChannelModel.

        Whether the insecure customer name and email passed from Javascript should be ignored.  # noqa: E501

        :param ignore_js_customer_info: The ignore_js_customer_info of this SmoochChatOrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._ignore_js_customer_info = ignore_js_customer_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SmoochChatOrgChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmoochChatOrgChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.smart_links_api import SmartLinksApi  # noqa: E501
from swagger_client.rest import ApiException


class TestSmartLinksApi(unittest.TestCase):
    """SmartLinksApi unit test stubs"""

    def setUp(self):
        self.api = SmartLinksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_smart_link(self):
        """Test case for add_smart_link

        Creates a Smart Link  # noqa: E501
        """
        pass

    def test_delete_smart_link(self):
        """Test case for delete_smart_link

        Deletes a Smart Link  # noqa: E501
        """
        pass

    def test_get_smart_link1(self):
        """Test case for get_smart_link1

        Gets the details of a specific Smart Link  # noqa: E501
        """
        pass

    def test_get_smart_links(self):
        """Test case for get_smart_links

        Gets all the Smart Links in the org  # noqa: E501
        """
        pass

    def test_update_smart_link(self):
        """Test case for update_smart_link

        Modifies a Smart Link  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
